==> camel-k-model-v1-6.5.0-sources.jar: io/fabric8/camelk/v1/BuildahTaskFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildahTaskFluentImpl<A extends BuildahTaskFluent<A>> extends BaseFluent<A> implements BuildahTaskFluent<A>{
  public BuildahTaskFluentImpl() {
  }
  public BuildahTaskFluentImpl(BuildahTask instance) {
    this.withBaseImage(instance.getBaseImage()); 
    this.withContextDir(instance.getContextDir()); 
    this.withImage(instance.getImage()); 
    this.withName(instance.getName()); 
    this.withRegistry(instance.getRegistry()); 
    this.withVerbose(instance.getVerbose()); 
  }
  private String baseImage;
  private String contextDir;
  private String image;
  private String name;
  private RegistrySpecBuilder registry;
  private Boolean verbose;
  public String getBaseImage() {
    return this.baseImage;
  }
  public A withBaseImage(String baseImage) {
    this.baseImage=baseImage; return (A) this;
  }
  public Boolean hasBaseImage() {
    return this.baseImage != null;
  }
  public String getContextDir() {
    return this.contextDir;
  }
  public A withContextDir(String contextDir) {
    this.contextDir=contextDir; return (A) this;
  }
  public Boolean hasContextDir() {
    return this.contextDir != null;
  }
  public String getImage() {
    return this.image;
  }
  public A withImage(String image) {
    this.image=image; return (A) this;
  }
  public Boolean hasImage() {
    return this.image != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildRegistry instead.
   * @return The buildable object.
   */
  @Deprecated
  public RegistrySpec getRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public RegistrySpec buildRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public A withRegistry(RegistrySpec registry) {
    _visitables.get("registry").remove(this.registry);
    if (registry!=null){ this.registry= new RegistrySpecBuilder(registry); _visitables.get("registry").add(this.registry);} else { this.registry = null; _visitables.get("registry").remove(this.registry); } return (A) this;
  }
  public Boolean hasRegistry() {
    return this.registry != null;
  }
  public A withNewRegistry(String address,String ca,Boolean insecure,String organization,String secret) {
    return (A)withRegistry(new RegistrySpec(address, ca, insecure, organization, secret));
  }
  public BuildahTaskFluent.RegistryNested<A> withNewRegistry() {
    return new BuildahTaskFluentImpl.RegistryNestedImpl();
  }
  public BuildahTaskFluent.RegistryNested<A> withNewRegistryLike(RegistrySpec item) {
    return new BuildahTaskFluentImpl.RegistryNestedImpl(item);
  }
  public BuildahTaskFluent.RegistryNested<A> editRegistry() {
    return withNewRegistryLike(getRegistry());
  }
  public BuildahTaskFluent.RegistryNested<A> editOrNewRegistry() {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): new RegistrySpecBuilder().build());
  }
  public BuildahTaskFluent.RegistryNested<A> editOrNewRegistryLike(RegistrySpec item) {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): item);
  }
  public Boolean getVerbose() {
    return this.verbose;
  }
  public A withVerbose(Boolean verbose) {
    this.verbose=verbose; return (A) this;
  }
  public Boolean hasVerbose() {
    return this.verbose != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BuildahTaskFluentImpl that = (BuildahTaskFluentImpl) o;
    if (baseImage != null ? !baseImage.equals(that.baseImage) :that.baseImage != null) return false;
    if (contextDir != null ? !contextDir.equals(that.contextDir) :that.contextDir != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (registry != null ? !registry.equals(that.registry) :that.registry != null) return false;
    if (verbose != null ? !verbose.equals(that.verbose) :that.verbose != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseImage,  contextDir,  image,  name,  registry,  verbose,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (baseImage != null) { sb.append("baseImage:"); sb.append(baseImage + ","); }
    if (contextDir != null) { sb.append("contextDir:"); sb.append(contextDir + ","); }
    if (image != null) { sb.append("image:"); sb.append(image + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (registry != null) { sb.append("registry:"); sb.append(registry + ","); }
    if (verbose != null) { sb.append("verbose:"); sb.append(verbose); }
    sb.append("}");
    return sb.toString();
  }
  public A withVerbose() {
    return withVerbose(true);
  }
  class RegistryNestedImpl<N> extends RegistrySpecFluentImpl<BuildahTaskFluent.RegistryNested<N>> implements BuildahTaskFluent.RegistryNested<N>,Nested<N>{
    RegistryNestedImpl(RegistrySpec item) {
      this.builder = new RegistrySpecBuilder(this, item);
    }
    RegistryNestedImpl() {
      this.builder = new RegistrySpecBuilder(this);
    }
    RegistrySpecBuilder builder;
    public N and() {
      return (N) BuildahTaskFluentImpl.this.withRegistry(builder.build());
    }
    public N endRegistry() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/BuildahTaskFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildahTaskFluentImpl<A extends BuildahTaskFluent<A>> extends BaseFluent<A> implements BuildahTaskFluent<A>{
  public BuildahTaskFluentImpl() {
  }
  public BuildahTaskFluentImpl(BuildahTask instance) {
    if (instance != null) {
      this.withBaseImage(instance.getBaseImage());
      this.withContextDir(instance.getContextDir());
      this.withImage(instance.getImage());
      this.withName(instance.getName());
      this.withRegistry(instance.getRegistry());
      this.withVerbose(instance.getVerbose());
    }
  }
  private String baseImage;
  private String contextDir;
  private String image;
  private String name;
  private RegistrySpecBuilder registry;
  private Boolean verbose;
  public String getBaseImage() {
    return this.baseImage;
  }
  public A withBaseImage(String baseImage) {
    this.baseImage=baseImage; return (A) this;
  }
  public Boolean hasBaseImage() {
    return this.baseImage != null;
  }
  public String getContextDir() {
    return this.contextDir;
  }
  public A withContextDir(String contextDir) {
    this.contextDir=contextDir; return (A) this;
  }
  public Boolean hasContextDir() {
    return this.contextDir != null;
  }
  public String getImage() {
    return this.image;
  }
  public A withImage(String image) {
    this.image=image; return (A) this;
  }
  public Boolean hasImage() {
    return this.image != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildRegistry instead.
   * @return The buildable object.
   */
  @Deprecated
  public RegistrySpec getRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public RegistrySpec buildRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public A withRegistry(RegistrySpec registry) {
    _visitables.get("registry").remove(this.registry);
    if (registry!=null){ this.registry= new RegistrySpecBuilder(registry); _visitables.get("registry").add(this.registry);} else { this.registry = null; _visitables.get("registry").remove(this.registry); } return (A) this;
  }
  public Boolean hasRegistry() {
    return this.registry != null;
  }
  public A withNewRegistry(String address,String ca,Boolean insecure,String organization,String secret) {
    return (A)withRegistry(new RegistrySpec(address, ca, insecure, organization, secret));
  }
  public BuildahTaskFluentImpl.RegistryNested<A> withNewRegistry() {
    return new BuildahTaskFluentImpl.RegistryNestedImpl();
  }
  public BuildahTaskFluentImpl.RegistryNested<A> withNewRegistryLike(RegistrySpec item) {
    return new BuildahTaskFluentImpl.RegistryNestedImpl(item);
  }
  public BuildahTaskFluentImpl.RegistryNested<A> editRegistry() {
    return withNewRegistryLike(getRegistry());
  }
  public BuildahTaskFluentImpl.RegistryNested<A> editOrNewRegistry() {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): new RegistrySpecBuilder().build());
  }
  public BuildahTaskFluentImpl.RegistryNested<A> editOrNewRegistryLike(RegistrySpec item) {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): item);
  }
  public Boolean getVerbose() {
    return this.verbose;
  }
  public A withVerbose(Boolean verbose) {
    this.verbose=verbose; return (A) this;
  }
  public Boolean hasVerbose() {
    return this.verbose != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildahTaskFluentImpl that = (BuildahTaskFluentImpl) o;
    if (!java.util.Objects.equals(baseImage, that.baseImage)) return false;

    if (!java.util.Objects.equals(contextDir, that.contextDir)) return false;

    if (!java.util.Objects.equals(image, that.image)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(registry, that.registry)) return false;

    if (!java.util.Objects.equals(verbose, that.verbose)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseImage,  contextDir,  image,  name,  registry,  verbose,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (baseImage != null) { sb.append("baseImage:"); sb.append(baseImage + ","); }
    if (contextDir != null) { sb.append("contextDir:"); sb.append(contextDir + ","); }
    if (image != null) { sb.append("image:"); sb.append(image + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (registry != null) { sb.append("registry:"); sb.append(registry + ","); }
    if (verbose != null) { sb.append("verbose:"); sb.append(verbose); }
    sb.append("}");
    return sb.toString();
  }
  public A withVerbose() {
    return withVerbose(true);
  }
  class RegistryNestedImpl<N> extends RegistrySpecFluentImpl<BuildahTaskFluentImpl.RegistryNested<N>> implements BuildahTaskFluentImpl.RegistryNested<N>,Nested<N>{
    RegistryNestedImpl(RegistrySpec item) {
      this.builder = new RegistrySpecBuilder(this, item);
    }
    RegistryNestedImpl() {
      this.builder = new RegistrySpecBuilder(this);
    }
    RegistrySpecBuilder builder;
    public N and() {
      return (N) BuildahTaskFluentImpl.this.withRegistry(builder.build());
    }
    public N endRegistry() {
      return and();
    }
    
  }
  
}
